﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using NAudio;
using NAudio.Wave;

namespace Dinofox_Viewer
{
    public partial class Form1 : Form
    {

        String filename;

        int filetype = 0; //order is as follows, starting with 1

        fileTextureDKR texFileDKR;
        fileAudioVox voxFile;

        WaveOutEvent wavHolder = new WaveOutEvent(); //audio stream holder for NAudio

        int treeNum;
        Bitmap curImg;
        Byte[] curVox;


        public Form1()
        {
            InitializeComponent();

            panel1.Hide();
            toolStripStatusLabel1.Text = "Welcome!";
        }

        private void Form1_Load(object sender, EventArgs e)
        {

        }
        private void loadFileToolStripMenuItem_Click(object sender, EventArgs e)
        {
            wavHolder.Stop();
            
            OpenFileDialog binofd = new OpenFileDialog() { Filter = "BIN files (*.bin)|*.bin" };
            if (binofd.ShowDialog() != System.Windows.Forms.DialogResult.OK) return;

            filename = Path.GetFileNameWithoutExtension(binofd.FileName);

            //TODO: make a function to handle the hide() and show() based on filetype passed to it

            switch(filename)
            {
                case "TEX":
                    panel1.Hide();
                    
                    texFileDKR = new fileTextureDKR(binofd.FileName);
                    filetype = 1;
                    pictureBox1.Show();
                    break;

                case "MPEG":
                    pictureBox1.Hide();
                    voxFile = new fileAudioVox(binofd.FileName);
                    filetype = 2;
                    panel1.Show();
                    break;

                default:
                    toolStripStatusLabel1.Text = "File " + binofd.FileName + " couldn't be loaded.";
                    break;
            }

            UpdateGUI();
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void loadableFilesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MessageBox.Show("Current loadable files are:" + Environment.NewLine + Environment.NewLine + "TEX.bin (Diddy Kong Racing leftovers)" + Environment.NewLine + "MPEG.bin (Dinosaur Planet voice acting)",
                "Loadable Files", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MessageBox.Show("Dinofox Viewer version 0.2.1 by 2Tie" + Environment.NewLine + "Started on 10/25/15" + Environment.NewLine + "Current revision made on 10/27/15" + Environment.NewLine + Environment.NewLine + "Made from scratch recycling code from xdaniel",
                "About", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void UpdateGUI()
        {
            treeView1.BeginUpdate();
            treeView1.Nodes.Clear();

            if(filetype == 1)//DKR texture file
            {

                for (int i = 0; i < texFileDKR.addresses.Count-1; i++)
                {
                    TreeNode newnode = new TreeNode(i + ": " + texFileDKR.addresses[i].ToString());
                    newnode.Tag = i;
                    treeView1.Nodes.Add(newnode);
                }

                toolStripStatusLabel1.Text = "Texture file loaded.";
            }

            if (filetype == 2)//DP voice acting file
            {

                for (int i = 0; i < voxFile.addresses.Count - 1; i++)
                {
                    TreeNode newnode = new TreeNode(i + ": " + voxFile.addresses[i].ToString());
                    newnode.Tag = i;
                    treeView1.Nodes.Add(newnode);
                }

                toolStripStatusLabel1.Text = "Audio file loaded.";
            }

            treeView1.EndUpdate();
        }

        private void treeView1_AfterSelect(object sender, TreeViewEventArgs e)
        {
            if(filetype == 1)//DKR texture file
            {
                treeNum = (int)((TreeView)sender).SelectedNode.Tag;
                curImg = texFileDKR.returnImg(treeNum);
                toolStripStatusLabel1.Text = "Texture " + treeNum + " loaded. W:" + curImg.Width + " H:" + curImg.Height;
                pictureBox1.Image = curImg;
            }
            if (filetype == 2)//DP voice acting file
            {
                wavHolder.Stop();
                treeNum = (int)((TreeView)sender).SelectedNode.Tag;
                curVox = voxFile.returnClip(treeNum);

                MemoryStream ms = new MemoryStream(curVox);
                var audReader = new Mp3FileReader(ms);
                wavHolder.Init(audReader);
                wavHolder.Play();

                toolStripStatusLabel1.Text = "Audio clip " + treeNum + " playing.";
            }
        }
    }
}
